@@ -38,6 +38,15 @@ class Either(Generic[A, B], Implicits, implicits=True):
             .flat_map2(Either.import_name)
         )
 
+    @staticmethod
+    def import_module(modname):
+        try:
+            mod = importlib.import_module(modname)
+        except ImportError as e:
+            return Left(e)
+        else:
+            return Right(mod)
+
     @property
     def is_right(self):
         return boolean.Boolean(isinstance(self, Right))
@@ -98,6 +107,10 @@ class Either(Generic[A, B], Implicits, implicits=True):
     def __iter__(self):
         return iter(self.to_list)
 
+    @property
+    def swap(self):
+        return Left(self.value) if self.is_right else Right(self.value)
+
 
 class Right(Either):
 
