@@ -7,8 +7,6 @@ from functools import reduce
 
 from toolz.itertoolz import cons
 
-from fn import _
-
 from amino import maybe, boolean
 from amino.logging import log
 from amino.tc.base import ImplicitsMeta, Implicits
@@ -57,6 +55,7 @@ class List(typing.List[A], Generic[A], Implicits, implicits=True,
 
     @staticmethod
     def random_string(num: int=10):
+        from amino.anon import _
         chars = string.ascii_letters + string.digits
         return ''.join(random.choice(chars) for _ in range(num))
 
@@ -69,9 +68,14 @@ class List(typing.List[A], Generic[A], Implicits, implicits=True,
         return List.wrap(data.splitlines())
 
     def lift(self, index: int) -> 'maybe.Maybe[A]':
-        return maybe.Maybe.from_call(self.__getitem__, index, exc=IndexError)
+        return (
+            (maybe.Just(self[index]) if len(self) > index else maybe.Empty())
+            if index >= 0 else
+            (maybe.Just(self[index]) if len(self) >= -index else maybe.Empty())
+        )
 
     def lift_all(self, index, *indexes):
+        from amino.anon import _
         def folder(z, n):
             return n.ap(z / _.cat)
         els = List.wrap(indexes) / self.lift
@@ -142,6 +146,7 @@ class List(typing.List[A], Generic[A], Implicits, implicits=True,
     __add__ = add
 
     def without(self, el) -> 'List[A]':
+        from amino.anon import _
         return self.filter(_ != el)
 
     __sub__ = without
@@ -162,6 +167,7 @@ class List(typing.List[A], Generic[A], Implicits, implicits=True,
         return self
 
     def index_of(self, target: Any):
+        from amino.anon import _
         return self.index_where(_ == target)
 
     @property
